@@ -15,12 +15,12 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-# pylint: disable=no-member
+
 """Microsoft SQLServer hook module"""
 
 import pymssql
 
-from airflow.hooks.dbapi import DbApiHook
+from airflow.providers.common.sql.hooks.sql import DbApiHook
 
 
 class MsSqlHook(DbApiHook):
@@ -38,13 +38,11 @@ class MsSqlHook(DbApiHook):
 
     def get_conn(
         self,
-    ) -> pymssql.connect:  # pylint: disable=protected-access,c-extension-no-member,no-member
+    ) -> pymssql.connect:
         """Returns a mssql connection object"""
-        conn = self.get_connection(
-            self.mssql_conn_id  # type: ignore[attr-defined]  # pylint: disable=no-member
-        )
-        # pylint: disable=c-extension-no-member
-        conn = pymssql.connect(  # pylint: disable=no-member
+        conn = self.get_connection(self.mssql_conn_id)  # type: ignore[attr-defined]
+
+        conn = pymssql.connect(
             server=conn.host,
             user=conn.login,
             password=conn.password,
@@ -55,10 +53,10 @@ class MsSqlHook(DbApiHook):
 
     def set_autocommit(
         self,
-        conn: pymssql.connect,  # pylint: disable=c-extension-no-member, no-member
+        conn: pymssql.connect,
         autocommit: bool,
     ) -> None:
         conn.autocommit(autocommit)
 
-    def get_autocommit(self, conn: pymssql.connect):  # pylint: disable=c-extension-no-member, no-member
+    def get_autocommit(self, conn: pymssql.connect):
         return conn.autocommit_state
